@@ -32,16 +32,57 @@ config_ready = False
 
 #####################################################################
 
-def setup( ) :
+def setup( config_user = None ) :
     global config_ready
-    if init( ) :
-        config_ready = True
-        return
 
-    s_log.write( "Not ready!" )
+    flag = init( config_user ) 
+
+    if not flag :
+        s_log.write( "Not setup ready!" )
+        return( falg )
+
+    unpack_key( )
+    checkup_workspacedir( )
+
+
+    config_ready = True
+
+    s_log.write( get_config( ) )
+
+    return( True )
+
+def checkup_workspacedir( ) :
+    wd = get_key( "sys/workspacedir" )
+    if not wd :
+        set_key( "sys/workspacedir" , "/tmp/sapiadapter" )
+
+def unpack_key( ) :
+
+    if "_CONTAINER_LOCAL_CONFIGENDPOINTKEY" in os.environ :
+        endpoint_key = os.environ["_CONTAINER_LOCAL_CONFIGENDPOINTKEY"]
+    else :
+        endpoint_key = get_key( "endpoint/key" )
+
+    if not endpoint_key : return
+
+    parts = endpoint_key.split( "|" )
+
+    endpoint_url_token = endpoint_key
+
+    if( len( parts ) == 2 ) :
+        endpoint_url_token = parts[ 0 ]
+        set_key_alt( "endpoint/host" , parts[ 1 ] )
+
+    url = endpoint_url_token[ 0:-67 ]
+    token = endpoint_url_token[ -67: ]
+    if( url[ 0:4 ] != "http" ) : url = "https://" + url
+
+    set_key_alt( "endpoint/url" , url )
+    set_key_alt( "endpoint/token" , token )
+
 
 def config_ready_get( ) :
-    return(config_ready)
+    return( config_ready )
 
 
 def get_config( ) :
@@ -148,7 +189,7 @@ def init( config_user = None ) :
     config[ "/config/maindir" ] = os.path.dirname( sys.modules[ "__main__" ].__file__ )
     config[ "/config/session" ] = s_util.uhash( )
 
-    s_log.write( config )
+    #s_log.write( config )
 
     if( config_user ) :
         config.update( config_user )
