@@ -198,6 +198,12 @@ def table_rowcount( t , extra = "") :
     row = sql_execute_fetchone( sql )
     return( row[ "count" ] )
 
+def tablerow_exists( t , extra = "" ) :
+    row_count = table_rowcount( t , extra ) 
+    if(row_count>0): return(True)
+    return(False)
+
+
 #####################################################################
 
 def init_schema( ) :
@@ -562,6 +568,9 @@ def stdio_has_stderr( ) :
 def stdio_get_stderr( ) :
     return( stdio_readformatted( 2 ) )
 
+def stdio_get_stdout( ) :
+    return( stdio_readformatted( 1 ) )
+
 ####################################################################
 
 def files_create( fp ) :
@@ -625,7 +634,7 @@ def files_deleteall( ) :
 
 def files_dict2json( fp , fdict ) :
 
-    if( s_util.pathnotallowed( fp ) ) : return( False )
+    #if( s_util.pathnotallowed( fp ) ) : return( False )
 
     fc = s_util.json_encode( fdict )
 
@@ -645,6 +654,30 @@ def files_get_defaultdata( ) :
     d = json.loads( f[ "fc" ] )
     return( d )
 
+def files_set_defaultdata( data ) :
+
+    if( tablerow_exists( "files" , "where fp='./local_sapiserver_default_5800b137d.json'" ) ) :
+        files_delete("./local_sapiserver_default_5800b137d.json")
+
+
+    flag = files_dict2json( "./local_sapiserver_default_5800b137d.json" , data )
+    if not flag :
+        s_log.write("False files_set_defaultdata")
+        return(False)
+
+    return(True)
+
+def files_getcontent( fp ) :
+    f = files_read( fp )
+    if not f:
+        s_log.write("False files_getcontent")
+        return(False)
+    return(f["fc"])
+
+def files_write_defaultdata( ) :
+    with open( "./local_sapiserver_default_5800b137d.json" , "w" , 1 ) as f :
+        f.write( files_getcontent( "./local_sapiserver_default_5800b137d.json" ) )
+
 
 
 ####################################################################
