@@ -85,12 +85,8 @@ def express( meta_inputs = { } , wait_timeout = 60 ) :
 
     #####################################################################
 
-    t1=uptime()
-
     jr = s_net.job_responsewait( jid , wait_timeout )
 
-    s_log.write(uptime()-t1)
-
     if( jr == False ) :
         s_log.write( "false job_wait" )
         return( False )
